# AwsIBox
AwsIBox = **AWS** **I**nfrastructure in a **Box**

### Guidelines:
- Infrastructure as code.
- Same cloudformation template for all environments and regions (Ex. development and production).
- Scalable as needed.

#### Note:
To easily manage the Cloudformation stacks use:
[AwsIBoxStackOps](https://github.com/mello7tre/AwsIBoxStackOps)

## Installation
`pip install awsibox`

## License

This software is distributed under the terms of the MIT [license](LICENSE).
